@@ -2,7 +2,7 @@ package Test2::Suite;
 use strict;
 use warnings;
 
-our $VERSION = '0.000068';
+our $VERSION = '0.000071'; # TRIAL
 
 1;
 
@@ -57,8 +57,36 @@ also produces undesirable side effects.
 
 =over 4
 
+=item Test2::V#
+
+These does not live in the bundle namespace as they are the primary ways to use
+Test2::Suite.
+
+The current latest is L<Test2::V0>.
+
+    use Test2::V0;
+    # strict and warnings are on for you now.
+
+    ok(...);
+
+    # Note: is does deep checking, unlike the 'is' from Test::More.
+    is(...);
+
+    ...
+
+    done_testing;
+
+This bundle includes every tool listed in the L</INCLUDED TOOLS> section below,
+except for L<Test2::Tools::ClassicCompare>. This bundle provides most of what
+anyone writing tests could need. This is also the preferred bundle/toolset of
+the L<Test2> author.
+
+See L<Test2::V0> for complete documentation.
+
 =item Extended
 
+B<** Deprecated **> See L<Test2::V0>
+
     use Test2::Bundle::Extended;
     # strict and warnings are on for you now.
 
